%% Initialise Workspace 

    clc
    clear
    %close all 
    
    % trying to identify the parameters of a model
    % x(k+1) = A(phi)x(k) + BU
    %  y = CX +DU
    %% Initialise some stuff
    nIterations = 1e1;
    T = 0.108;
    time_sim = 2*60;  
    nData = ceil(time_sim/T);
    t = linspace(0,time_sim,nData); 
    u = 0.5*square(2*pi*0.05*t)+0.5; % generate input to generate some data 
 
    %% generate a dataset with known parameters/ we use y to identify o vector
    o = [0.3, 0.9, 0.9, 0.8, 20];  %[  p_f2a; p_a2f; p_r2a; p_a2r; M]
    nStates = 2; % number of states of state space model
    x = NaN(nStates,nData);
    y = NaN(1,nData);
    x(:,1) = zeros(nStates,1); %initialize states of the system
    y(1) = 0; %initialize system output / measurement data
    
    for ii = 2:nData
        x(:,ii) = muscularFatigue(x(:,ii-1),u(ii),o);
        y(ii) = muscularFatigueOutput(x(:,ii),u(ii),o);
      
    end
    
    data.afTimes = (1:nData)*T;
    data.afValues = y;
    save('testData.mat', 'data')
    
%% Initialise some stuff

    Q = NaN(nIterations-1,1);
    phi = NaN(nIterations,5); % 5 parameters to identify in our case = [o,hp{1}] = [  p_f2a; p_a2f; p_r2a; p_a2r; M]
   
%% find parameters  

    phi(1,:) = [0.5, 0.5, 0.5, 0.5, 30]; % initializeparameter vector
    options = optimset('Display','off','TolFun',1e-5,'TolX',1e-5); 
    lBound = [0,0,0,0,0]; % set upper and lower bands of parameters for identification
    uBound = [1,1,1,1,100];
    progressbar;
    fun = @(o) costFunction(y,u,o);
    for kk = 1:nIterations-1
        Q(kk) = fun(phi(kk,:));
        phi(kk+1,:) = fmincon(fun,phi(kk,:),[],[],[],[],lBound,uBound,[],options);
        progressbar(kk/(nIterations-1));
    end
    
    
    
%% simulate the model with identified parameters
    [mu,y_est] = SimulateSystem(y,u,phi(end,:)); %simulated states and output signal
    
%% Plot stuff
    close all 

    t_min = (1:nData)*T/60;
    
    fprintf('\t phi f2a\t = %.3f\n',phi(end,1));
    fprintf('\t phi a2f\t = %.3f\n',phi(end,2));
    fprintf('\t phi r2a\t = %.3f\n',phi(end,3));
    fprintf('\t phi a2r\t = %.3f\n',phi(end,4));
    fprintf('\t M \t = %.6f\n',phi(end,5));
    fprintf('\t rmse = %.3f\n',sqrt(Q(end)/nData));

    figure(1)
    subplot(2,1,1)
    plot(t_min,x(1,:),'r',t_min,mu(1,:),'b','LineWidth',2)
    xlim([min(t_min),max(t_min)])
    title('m_f')
    xlabel('time [min]')
    legend('true','estimated')
    subplot(2,1,2)
    plot(t_min,x(2,:),'r',t_min,mu(2,:),'b','LineWidth',2)
    xlim([min(t_min),max(t_min)])
    title('m_a')
    xlabel('time [min]')
    legend('true','estimated')
    
    figure(2)
    plot(t_min,y,'r',t_min,y_est,'b','LineWidth',2)
    hold on
    plot(t_min,10*u,'g','LineWidth',2)
    xlim([min(t_min),max(t_min)])
    xlabel('time [min]')
    title('input-output')
    legend('true','estimated','input')
    
    figure(3)
    subplot(1,4,1)
    plot([1,nIterations],[o(1),o(1)],'r--',1:nIterations,phi(:,1),'b','LineWidth',2)
    title('phi fatigue to active')
    xlim([1,nIterations])
    ylim([0,1])
    xlabel('iterations')
    legend('true','estimated')
    subplot(1,4,2)
    plot([1,nIterations],[o(2),o(2)],'r--',1:nIterations,phi(:,2),'b','LineWidth',2)
    title('phi active to fatigue')
    xlim([1,nIterations])
    ylim([0,1])
    xlabel('iterations')
    legend('true','estimated')
    subplot(1,4,3)
    plot([1,nIterations],[o(3),o(3)],'r--',1:nIterations,phi(:,3),'b','LineWidth',2)
    title('phi resting to active')
    xlim([1,nIterations])
    ylim([0,1])
    xlabel('iterations')
    legend('true','estimated')
    subplot(1,4,4)
    plot([1,nIterations],[o(4),o(4)],'r--',1:nIterations,phi(:,4),'b','LineWidth',2)
    title('phi active to resting')
    xlim([1,nIterations])
    ylim([0,1])
    xlabel('iterations')
    legend('true','estimated')
    
    
    figure(4)
    plot(1:nIterations-1,Q,'LineWidth',2)
    title('MSE')
    xlabel('iterations')
    ylabel('Cost function')
    
    